@@ -7,8 +7,8 @@ import unittest
 
 import pygame
 
-from yadraw import logging_config
-import yadraw as yd
+from yatools import logging_config
+import yadraw.yadraw as yd
 
 logging_config.init()
 
